/*
 * Copyright 2023 The Android Open Source Project
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package androidx.camera.extensions.internal;

import android.graphics.ImageFormat;
import android.util.Pair;
import android.util.Size;

import androidx.annotation.NonNull;
import androidx.annotation.RequiresApi;
import androidx.camera.core.ImageAnalysis;
import androidx.camera.core.impl.ConfigProvider;
import androidx.camera.core.impl.ImageAnalysisConfig;

import java.util.ArrayList;
import java.util.List;

/**
 * Provides extensions related configs for image analysis
 */
@RequiresApi(21) // TODO(b/200306659): Remove and replace with annotation on package-info.java
public class ImageAnalysisConfigProvider implements ConfigProvider<ImageAnalysisConfig> {
    private final VendorExtender mVendorExtender;
    public ImageAnalysisConfigProvider(
            @NonNull VendorExtender vendorExtender) {
        mVendorExtender = vendorExtender;
    }

    @NonNull
    @Override
    public ImageAnalysisConfig getConfig() {
        ImageAnalysis.Builder builder = new ImageAnalysis.Builder();
        Size[] sizes = mVendorExtender.getSupportedYuvAnalysisResolutions();
        List<Pair<Integer, Size[]>> sizeList = new ArrayList<>();
        if (sizes != null && sizes.length > 0) {
            sizeList.add(new Pair<>(ImageFormat.YUV_420_888, sizes));
        }
        builder.setSupportedResolutions(sizeList);
        return builder.getUseCaseConfig();
    }
}
